import lodash from 'lodash'
import { interact, replaceApiParams } from '../../utils'
import apis from '../../config/api'

export default {
  namespaced: true,
  state: {
    notices: {},
    detail: {}
  },
  mutations: {
    updateList (state, payload) {
      state.notices = payload || {}
    },
    updateDetail (state, payload) {
      state.detail = payload || {}
    }
  },
  actions: {
    setDetailNull ({ commit }) {
      commit('updateDetail', {})
    },
    getNoticeList ({ commit }, payload) {
      const api = lodash.get(apis, 'notice.list')
      interact(api, payload).then((data) => {
        commit('updateList', data)
      })
    },
    getDetail ({ commit }, payload) {
      const api = replaceApiParams(lodash.get(apis, 'notice.detail'), payload)
      interact(api).then((data) => {
        commit('updateDetail', data)
      })
    },
    addNotice ( _, payload) {
      const { onSuccess } = payload
      const api = lodash.get(apis, 'notice.add')
      interact(api, payload.detail).then((data) => {
        onSuccess(data)
      })
    },
    editNotice ( _, payload) {
      const { onSuccess } = payload
      const api = lodash.get(apis, 'notice.edit')
      interact(api, payload.detail).then((data) => {
        onSuccess(data)
      })
    },
    deleteNotice ( _, payload) {
      return new Promise((resolve, reject) => {
        const api = replaceApiParams(lodash.get(apis, 'notice.delete'), payload)
        interact(api).then((data) => {
          resolve(data)
        }).catch(() => {
          reject()
        })
      })
    }
  }
}
